@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "genericpluginmanager.h"
@@ -59,7 +47,7 @@ public:
     void loadPlugin(GenericPluginInfo *item);
     QVector<GenericPlugin *> pluginsList() const;
     bool initializePlugins();
-    QString serviceTypeName;
+    QString pluginDirectory;
     QString pluginName;
     QVector<GenericPluginInfo> mPluginList;
 
@@ -69,7 +57,7 @@ public:
     GenericPlugin *pluginFromIdentifier(const QString &id);
 private:
     QVector<PluginUtilData> mPluginDataList;
-    GenericPluginManager *q;
+    GenericPluginManager *const q;
 };
 
 QString GenericPluginManagerPrivate::configGroupName() const
@@ -88,12 +76,10 @@ bool GenericPluginManagerPrivate::initializePlugins()
         return true;
     }
 
-    if (serviceTypeName.isEmpty() || pluginName.isEmpty()) {
+    if (pluginDirectory.isEmpty() || pluginName.isEmpty()) {
         return false;
     }
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(pluginName, [this](const KPluginMetaData &md) {
-        return md.serviceTypes().contains(serviceTypeName);
-    });
+    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(pluginDirectory);
 
     const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(configGroupName(), configPrefixSettingKey());
     QVectorIterator<KPluginMetaData> i(plugins);
@@ -185,14 +171,14 @@ bool GenericPluginManager::initializePlugins()
     return d->initializePlugins();
 }
 
-void GenericPluginManager::setServiceTypeName(const QString &serviceName)
+void GenericPluginManager::setPluginDirectory(const QString &directory)
 {
-    d->serviceTypeName = serviceName;
+    d->pluginDirectory = directory;
 }
 
-QString GenericPluginManager::serviceTypeName() const
+QString GenericPluginManager::pluginDirectory() const
 {
-    return d->serviceTypeName;
+    return d->pluginDirectory;
 }
 
 void GenericPluginManager::setPluginName(const QString &pluginName)
