@@ -1,25 +1,13 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "migrateapplicationfiles.h"
 #include "pimcommon_debug.h"
 
-#include <kdelibs4migration.h>
+#include <Kdelibs4Migration>
 #include <KSharedConfig>
 #include <KConfigGroup>
 #include <QFile>
@@ -31,18 +19,12 @@ using namespace PimCommon;
 class PimCommon::MigrateApplicationFilesPrivate
 {
 public:
-    MigrateApplicationFilesPrivate()
-        : mMigrateApplicationVersion(1)
-        , mCurrentConfigVersion(0)
-    {
-    }
-
     QVector<MigrateFileInfo> mMigrateInfoList;
     QString mConfigFileName;
     QString mApplicationName;
     Kdelibs4Migration mMigration;
-    int mMigrateApplicationVersion;
-    int mCurrentConfigVersion;
+    int mMigrateApplicationVersion = 1;
+    int mCurrentConfigVersion = 0;
 };
 
 MigrateApplicationFiles::MigrateApplicationFiles(QObject *parent)
