@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "shareserviceurlmanager.h"
@@ -31,23 +19,22 @@ class PimCommon::ShareServiceUrlManagerPrivate
 {
 public:
     explicit ShareServiceUrlManagerPrivate(ShareServiceUrlManager *qq)
-        : mMenu(nullptr)
-        , q(qq)
+        : q(qq)
     {
     }
 
-    QIcon typeToIcon(ShareServiceUrlManager::ServiceType type) const;
-    QString typeToI18n(ShareServiceUrlManager::ServiceType type) const;
+    Q_REQUIRED_RESULT QIcon typeToIcon(ShareServiceUrlManager::ServiceType type) const;
+    Q_REQUIRED_RESULT QString typeToI18n(ShareServiceUrlManager::ServiceType type) const;
     void initializeMenu();
     KActionMenu *mMenu = nullptr;
-    ShareServiceUrlManager *q = nullptr;
+    ShareServiceUrlManager *const q;
 };
 
 void ShareServiceUrlManagerPrivate::initializeMenu()
 {
     mMenu = new KActionMenu(QIcon::fromTheme(QStringLiteral("document-share")), i18n("Share On..."), q);
     for (int i = 0; i < ShareServiceUrlManager::ServiceEndType; ++i) {
-        const ShareServiceUrlManager::ServiceType type = static_cast<ShareServiceUrlManager::ServiceType>(i);
+        const auto type = static_cast<ShareServiceUrlManager::ServiceType>(i);
         QAction *action = new QAction(i18nc("@action:inmenu Share On...", "%1", typeToI18n(type)), q);
         action->setData(QVariant::fromValue(type));
         const QIcon icon = typeToIcon(type);
@@ -140,7 +127,7 @@ KActionMenu *ShareServiceUrlManager::menu() const
 void ShareServiceUrlManager::slotSelectServiceUrl(QAction *act)
 {
     if (act) {
-        const ServiceType type = act->data().value<PimCommon::ShareServiceUrlManager::ServiceType>();
+        const auto type = act->data().value<PimCommon::ShareServiceUrlManager::ServiceType>();
         Q_EMIT serviceUrlSelected(type);
     }
 }
