@@ -1,33 +1,9 @@
 /*
- * Copyright (c) 2011-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify it
- *  under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- *  In addition, as a special exception, the copyright holders give
- *  permission to link the code of this program with any edition of
- *  the Qt library by Trolltech AS, Norway (or with modified versions
- *  of Qt that use the same license as Qt), and distribute linked
- *  combinations including the two.  You must obey the GNU General
- *  Public License in all respects for all of the code used other than
- *  Qt.  If you modify this file, you may extend this exception to
- *  your version of the file, but you are not obligated to do so.  If
- *  you do not wish to do so, delete this exception statement from
- *  your version.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 #include "renamefiledialog.h"
-#include "kio_version.h"
 #include <kseparator.h>
 #include <QLineEdit>
 #include <QPushButton>
@@ -50,22 +26,18 @@ class Q_DECL_HIDDEN PimCommon::RenameFileDialog::RenameFileDialogPrivate
 public:
     RenameFileDialogPrivate(const QUrl &_url, RenameFileDialog *qq)
         : url(_url)
-        , applyAll(nullptr)
-        , renameBtn(nullptr)
-        , suggestNewNameBtn(nullptr)
-        , nameEdit(nullptr)
         , q(qq)
     {
     }
 
-    QString suggestName(const QUrl &baseURL, const QString &oldName);
+    Q_REQUIRED_RESULT QString suggestName(const QUrl &baseURL, const QString &oldName);
 
-    QUrl url;
+    const QUrl url;
     QCheckBox *applyAll = nullptr;
     QPushButton *renameBtn = nullptr;
     QPushButton *suggestNewNameBtn = nullptr;
     QLineEdit *nameEdit = nullptr;
-    RenameFileDialog *q = nullptr;
+    RenameFileDialog *const q;
 };
 
 QString PimCommon::RenameFileDialog::RenameFileDialogPrivate::suggestName(const QUrl &baseURL, const QString &oldName)
@@ -125,12 +97,12 @@ RenameFileDialog::RenameFileDialog(const QUrl &url, bool multiFiles, QWidget *pa
     , d(new RenameFileDialogPrivate(url, this))
 {
     setWindowTitle(i18nc("@title:window", "File Already Exists"));
-    QVBoxLayout *pLayout = new QVBoxLayout(this);
+    auto *pLayout = new QVBoxLayout(this);
 
     QLabel *label = new QLabel(xi18n("A file named <filename>%1</filename> already exists. Do you want to overwrite it?", url.fileName()), this);
     pLayout->addWidget(label);
 
-    QHBoxLayout *renameLayout = new QHBoxLayout();
+    auto *renameLayout = new QHBoxLayout();
     pLayout->addLayout(renameLayout);
 
     d->nameEdit = new QLineEdit(this);
@@ -141,7 +113,7 @@ RenameFileDialog::RenameFileDialog(const QUrl &url, bool multiFiles, QWidget *pa
     renameLayout->addWidget(d->suggestNewNameBtn);
     connect(d->suggestNewNameBtn, &QPushButton::clicked, this, &RenameFileDialog::slotSuggestNewNamePressed);
 
-    QPushButton *overWrite = new QPushButton(this);
+    auto *overWrite = new QPushButton(this);
     KStandardGuiItem::assign(overWrite, KStandardGuiItem::Overwrite);
     connect(overWrite, &QPushButton::clicked, this, &RenameFileDialog::slotOverwritePressed);
 
@@ -154,7 +126,7 @@ RenameFileDialog::RenameFileDialog(const QUrl &url, bool multiFiles, QWidget *pa
     KSeparator *separator = new KSeparator(this);
     pLayout->addWidget(separator);
 
-    QHBoxLayout *layout = new QHBoxLayout();
+    auto *layout = new QHBoxLayout();
     pLayout->addLayout(layout);
 
     if (multiFiles) {
@@ -201,11 +173,7 @@ void RenameFileDialog::slotRenamePressed()
     if (newName().isLocalFile()) {
         fileExists = QFile::exists(newName().path());
     } else {
-#if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
-        auto job = KIO::stat(newName(), KIO::StatJob::DestinationSide, 0);
-#else
         auto job = KIO::statDetails(newName(), KIO::StatJob::DestinationSide, KIO::StatBasic);
-#endif
         KJobWidgets::setWindow(job, this);
         fileExists = job->exec();
     }
